summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRogério Brito <rbrito@ime.usp.br>2017-06-28 22:22:22 -0400
committerAlexei Podtelezhnikov <apodtele@gmail.com>2017-06-28 22:22:22 -0400
commit3e4acb6856a5957ca98700bc66b97d64f54b0503 (patch)
tree2bde6b4b1ec645ac0498dc75f64833ddd0f9a86c
parent49da433aa4830d8dc0710606752074c3724ed969 (diff)
The man page and spelling fixes.
-rw-r--r--fondu.14
-rw-r--r--setfondname.145
-rw-r--r--ufond.c8
3 files changed, 51 insertions, 6 deletions
diff --git a/fondu.1 b/fondu.1
index c3da88c..4e4cc48 100644
--- a/fondu.1
+++ b/fondu.1
@@ -23,7 +23,7 @@ bare Macintosh resource forks,
or data fork resource files (.dfont, as used by MacOS X).
A bare resource fork may be generated easily be copying a file with a resource
fork onto a diskette (or zip drive) using DOS format.
-\." how to do this, explicitly?
+.\" how to do this, explicitly?
The Macintosh will create a folder called resource.frk
(invisible on the Macintosh itself),
in which the resource fork will reside as a bare file.
@@ -38,7 +38,7 @@ or bare resource fork files.
Force overwriting of the original file.
.TP
.B \-inquire
-Prompt for input before overwriting files. This overrides -force.
+Prompt for input before overwriting files. This overrides \-force.
.TP
.B \-show
Print out each file as it is created.
diff --git a/setfondname.1 b/setfondname.1
new file mode 100644
index 0000000..9f4b9a4
--- /dev/null
+++ b/setfondname.1
@@ -0,0 +1,45 @@
+.\" Hey, EMACS: -*- nroff -*-
+.\" First parameter, NAME, should be all caps
+.\" Second parameter, SECTION, should be 1-8, maybe w/ subsection
+.\" other parameters are allowed: see man(7), man(1)
+.TH SETFONDNAME 1 "August 28, 2005"
+.\" Please adjust this date whenever revising the manpage.
+.\"
+.\" Some roff macros, for reference:
+.\" .nh disable hyphenation
+.\" .hy enable hyphenation
+.\" .ad l left justify
+.\" .ad b justify to both left and right margins
+.\" .nf disable filling
+.\" .fi enable filling
+.\" .br insert line break
+.\" .sp <n> insert n+1 empty lines
+.\" for manpage-specific macros, see man(7)
+.SH NAME
+setfondname \- sets FOND name
+.SH SYNOPSIS
+.B setfondname
+.RI [ options ] " file"
+.SH DESCRIPTION
+.B setfondname
+sets FOND name.
+.SH OPTIONS
+A summary of options is included below.
+.TP
+.B \-name\fR=\fInewname
+Specify new FOND name.
+.TP
+.B \-help
+Display usage information.
+.SH SEE ALSO
+.BR fondu (1),
+.BR ufond (1),
+.BR showfond (1),
+.BR dfont2res (1),
+.BR tobin (1),
+.BR frombin (1),
+.BR lumper (1).
+.br
+.SH AUTHOR
+This manual page was written by Hanna Wallach <hmw26@cam.ac.uk>,
+for the Debian project (but may be used by others).
diff --git a/ufond.c b/ufond.c
index 8bdc3c2..19ce254 100644
--- a/ufond.c
+++ b/ufond.c
@@ -43,8 +43,8 @@
/* We strip off things like Italic, Bold, Oblique, Condensed, "-" to get a family name */
/* We collect all files into families */
/* We generate one FOND for each family and put the bdf and ttf into it */
/* We generate one seperate resource file for each ps font in the family */
/* If we do not have a plain style then make a seperate FOND for each style */
/* and pretend each is plain */
/* If we have a PS font style with no matching bdf (ie. no metrics) then */
/* complain (but make an entry for it in the fond anyway?) */
@@ -107,8 +107,8 @@ static void Usage(char *prog) {
fprintf( stderr, " -res\tPuts the output into a data file containing a resource fork\n\t\t(you have to figure out how to get it into a real resource fork)" );
fprintf( stderr, " -script [name|code]\tThe name should be the name of a mac script\n\t\tlike Roman or Cyrillic (not all names are recognized)\n\t\tthe code can be a number representing a script\n" );
fprintf( stderr, "A list of bdf/ttf files all with the same family name will be merged into\n" );
- fprintf( stderr, "one FOND and all stored in one output files. Any pfb files will be refered\n" );
- fprintf( stderr, "to in the FOND but will live in a seperate file.\n" );
+ fprintf( stderr, "one FOND and all stored in one output files. Any pfb files will be referred\n" );
+ fprintf( stderr, "to in the FOND but will live in a separate file.\n" );
exit( 1 );
}
@@ -43,8 +43,8 @@
/* We collect all files into families */
/* We generate one FOND for each family and put the bdf and ttf into it */
-/* We generate one seperate resource file for each ps font in the family */
-/* If we do not have a plain style then make a seperate FOND for each style */
+/* We generate one separate resource file for each ps font in the family */
+/* If we do not have a plain style then make a separate FOND for each style */
/* and pretend each is plain */
/* If we have a PS font style with no matching bdf (ie. no metrics) then */